============
Installation
============

At the command line::

    $ easy_install gls_unibox_api

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv gls_unibox_api
    $ pip install gls_unibox_api
